diff src/quickfix.c @ 3267:4eda43e1fce0 v7.3.402

updated for version 7.3.402 Problem: When jumping to the first error a line of the buffer is sometimes redrawn on top of the list of errors. Solution: Do not call update_topline_redraw() if the display was scrolled up.
author Bram Moolenaar <bram@vim.org>
date Fri, 20 Jan 2012 13:28:34 +0100
parents 9eb7fdfb5e63
children 5850b5827691
line wrap: on
line diff
--- a/src/quickfix.c
+++ b/src/quickfix.c
@@ -1842,8 +1842,10 @@ win_found:
 #endif
 	if (print_message)
 	{
-	    /* Update the screen before showing the message */
-	    update_topline_redraw();
+	    /* Update the screen before showing the message, unless the screen
+	     * scrolled up. */
+	    if (!msg_scrolled)
+		update_topline_redraw();
 	    sprintf((char *)IObuff, _("(%d of %d)%s%s: "), qf_index,
 		    qi->qf_lists[qi->qf_curlist].qf_count,
 		    qf_ptr->qf_cleared ? _(" (line deleted)") : "",